@@ -74,21 +74,24 @@ objects, :term:`string`, in addition to
 
 from __future__ import absolute_import
 
-from datetime import tzinfo, datetime, timedelta
-import re
 import copy
-import six
+import re
 
+from datetime import tzinfo, datetime, timedelta
+import six
 from .config import ENFORCE_INTEGER_RANGE
 from ._utils import _ensure_unicode, _hash_item, _format, _to_unicode, \
     _eq_item
 
-if six.PY2:
-    # pylint: disable=invalid-name,undefined-variable
-    _Longint = long  # noqa: F821
+if six.PY3:
+    from datetime import timezone
+
+if six.PY3:
+    _Longint = int  # pylint: disable=invalid-name
+    # Make Cython happy by defining long
+    long = int  # pylint: disable=invalid-name
 else:
-    # pylint: disable=invalid-name
-    _Longint = int
+    _Longint = long  # pylint: disable=invalid-name
 
 
 __all__ = ['cimtype', 'type_from_name', 'MinutesFromUTC', 'CIMType',
@@ -361,6 +364,7 @@ class CIMType(SlottedPickleMixin):  # pylint: disable=too-few-public-methods
 
 
 class Char16(CIMType, six.text_type):
+    # pylint: disable=too-few-public-methods
     """
     A value of CIM data type char16.
 
@@ -655,11 +659,18 @@ class CIMDateTime(_CIMComparisonMixin, CIMType):
         A positive value indicates minutes east of UTC, and a negative
         value indicates minutes west of UTC.
         """
-        utc = datetime.utcnow()
-        local = datetime.now()
-        if local < utc:
-            return - int(float((utc - local).seconds) / 60 + .5)
-        return int(float((local - utc).seconds) / 60 + .5)
+        if six.PY2:
+            # Effective Python 3.12, utcnow() deprecated, it returns
+            # naive datetime object and warning msg. timezone does
+            # not exist for python 2.7; use utcnow(timezone.utc).
+            utc_unaware = datetime.utcnow()
+        else:
+            utc_unaware = datetime.now(timezone.utc).replace(tzinfo=None)  # noqa: E501 pylint: disable=E0606
+
+        local_unaware = datetime.now()
+        if local_unaware < utc_unaware:
+            return - int(float((utc_unaware - local_unaware).seconds) / 60 + .5)
+        return int(float((local_unaware - utc_unaware).seconds) / 60 + .5)
 
     @classmethod
     def now(cls, tzi=None):
