@@ -49,12 +49,12 @@ __all__ = ['BaseOperationRecorder', 'TestClientRecorder',
            'LogOperationRecorder',
            'OpArgs', 'OpResult', 'HttpRequest', 'HttpResponse']
 
-if six.PY2:
-    # pylint: disable=invalid-name, undefined-variable
-    _Longint = long  # noqa: F821
+if six.PY3:
+    _Longint = int  # pylint: disable=invalid-name
+    # Make Cython happy by defining long
+    long = int  # pylint: disable=invalid-name
 else:
-    # pylint: disable=invalid-name
-    _Longint = int
+    _Longint = long  # pylint: disable=invalid-name
 
 OpArgsTuple = namedtuple("OpArgsTuple", ["method", "args"])
 
@@ -618,8 +618,8 @@ class LogOperationRecorder(BaseOperationRecorder):
             # Format the 'summary' and 'paths' detail_levels
             if self.api_detail_level == 'summary':  # pylint: disable=R1705
                 if isinstance(ret, list):
-                    if ret:
-                        ret_type = type(ret[0]).__name__ if ret else ""
+                    if len(ret) > 0:
+                        ret_type = type(ret[0]).__name__
                         return _format("list of {0}; count={1}",
                                        ret_type, len(ret))
                     return "Empty"
