@@ -32,7 +32,7 @@ DEBUG="false"
 VERBOSE="true"
 
 MYNAME=$(basename "$0")
-MYDIR=$(dirname "$0")    # Directory of this script, as seen by caller
+MYDIR=$(abspath $(dirname "$0"))  # Absolute path of directory of this script
 
 # Repo root dir, as seen by caller
 # Using MYDIR makes the script run with any caller's CWD.
@@ -100,6 +100,15 @@ function verbose()
   fi
 }
 
+function heading()
+{
+  local msg
+  msg="$1"
+  echo ""
+  echo -e "${green}${msg}${endcolor}"
+  echo ""
+}
+
 function info()
 {
   local msg
@@ -185,11 +194,6 @@ function make_virtualenv()
   run "pip install pip $PIP_OPTS" "Reinstalling pip with PACKAGE_LEVEL=$PACKAGE_LEVEL"
   run "pip install setuptools $PIP_OPTS -c $(abspath $ROOT_DIR/requirements.txt)" "Reinstalling setuptools with PACKAGE_LEVEL=$PACKAGE_LEVEL and constraints from requirements.txt"
   run "pip install wheel $PIP_OPTS" "Reinstalling wheel with PACKAGE_LEVEL=$PACKAGE_LEVEL"
-
-  verbose "Virtualenv before actual install test:"
-  verbose "Pip version: $(pip --version 2>&1)"
-  verbose "Packages:"
-  pip list --format=columns 2>/dev/null || pip list 2>/dev/null
 }
 
 function remove_virtualenv()
@@ -213,6 +217,15 @@ function remove_virtualenv()
   fi
 }
 
+function list_virtualenv()
+{
+  local curdir msg
+  curdir="$1"
+  msg="$2"
+  echo "$msg"
+  sh -c "cd $curdir; pip list --format=columns || pip list"
+}
+
 function assert_eq()
 {
   local v1 v2
@@ -238,11 +251,12 @@ function run()
     verbose "$msg"
   fi
   if [[ "$DEBUG" == "true" ]]; then
-    echo "Debug: running in this shell: $cmd"
+    echo "Debug: Command: $cmd"
     eval "$cmd"
     rc=$?
     echo "Debug: command returns: rc=$rc"
   else
+    verbose "Command: $cmd"
     eval "$cmd" >$CMD_LOG_FILE 2>&1
     rc=$?
   fi
@@ -263,10 +277,12 @@ function call()
     verbose "$msg"
   fi
   if [[ "$DEBUG" == "true" ]]; then
-    echo "Debug: running in sub-shell: $cmd"
+    echo "Debug: Command (in subshell): $cmd"
     sh -c "$cmd"
     rc=$?
+    echo "Debug: command returns: rc=$rc"
   else
+    verbose "Command (in subshell): $cmd"
     sh -c "$cmd" >$CMD_LOG_FILE 2>&1
     rc=$?
   fi
@@ -284,10 +300,12 @@ function assert_run_ok()
   cmd="$1"
   msg="$2"
   if [[ "$DEBUG" == "true" ]]; then
-    echo "Debug: running in this shell: $cmd"
+    echo "Debug: Command: $cmd"
     eval "$cmd"
     rc=$?
+    echo "Debug: command returns: rc=$rc"
   else
+    verbose "Command: $cmd"
     eval "$cmd" >$CMD_LOG_FILE 2>&1
     rc=$?
   fi
@@ -308,10 +326,12 @@ function assert_run_fails()
   cmd="$1"
   msg="$2"
   if [[ "$DEBUG" == "true" ]]; then
-    echo "Debug: running in this shell: $cmd"
+    echo "Debug: Command: $cmd"
     eval "$cmd"
     rc=$?
+    echo "Debug: command returns: rc=$rc"
   else
+    verbose "Command: $cmd"
     eval "$cmd" >$CMD_LOG_FILE 2>&1
     rc=$?
   fi
@@ -332,25 +352,32 @@ function ensure_uninstalled()
   pkg="$1"
   cmd="pip uninstall -y -q $pkg"
   if [[ "$DEBUG" == "true" ]]; then
-    echo "Debug: running: $cmd"
+    echo "Debug: Command: $cmd"
+    eval "$cmd"
+    rc=$?
+    echo "Debug: command returns: rc=$rc"
+  else
+    verbose "Command: $cmd"
+    eval "$cmd" >/dev/null 2>/dev/null
   fi
-  eval $cmd >/dev/null 2>/dev/null
 }
 
 function assert_import_ok()
 {
-  local module
+  local module dir
   module="$1"
-  verbose "Checking for successful import of module: $module"
-  assert_run_ok "python -c \"import ${module}\"" "Python module '${module}' cannot be imported"
+  dir="$2"
+  verbose "Checking for successful import of module $module in directory $dir"
+  assert_run_ok "cd ${dir}; python -c \"import ${module}\"" "Python module '${module}' cannot be imported in directory $dir"
 }
 
 function assert_import_fails()
 {
-  local module
+  local module dir
   module="$1"
-  verbose "Checking for failing import of module: $module"
-  assert_run_fails "python -c \"import ${module}\"" "Python module '${module}' can be imported but should have failed"
+  dir="$2"
+  verbose "Checking for failing import of module $module in directory $dir"
+  assert_run_fails "cd ${dir}; python -c \"import ${module}\"" "Python module '${module}' can be imported in directory $dir but should have failed"
 }
 
 function get_ply_version()
@@ -411,7 +438,7 @@ function ensure_fresh()
 
 function prep()
 {
-  info "Preparing for the tests"
+  heading "Preparing for the tests"
 
   if [[ -d $TMP_TEST_DIR ]]; then
     echo "Removing test directory: $TMP_TEST_DIR"
@@ -433,7 +460,7 @@ function prep()
 
 function cleanup()
 {
-  info "Cleaning up from the tests"
+  heading "Cleaning up from the tests"
 
   if [[ "$DEBUG" == "true" ]]; then
     echo "Debug: Not removing $TMP_TEST_DIR for debug inspection"
@@ -459,29 +486,15 @@ function cleanup_egg_file()
 function test1()
 {
   testcase="test1"
-  info "Testcase $testcase: Pip install from repo root directory: $ROOT_DIR"
+  heading "Testcase $testcase: Pip install from repo root directory: $ROOT_DIR"
   make_virtualenv "$testcase"
+  list_virtualenv "$TMP_TEST_DIR" "Python packages in virtualenv before installation (PACKAGE_LEVEL=$PACKAGE_LEVEL)"
 
   call "cd $ROOT_DIR; pip install . $PIP_OPTS" "Installing with pip from repo root directory (PACKAGE_LEVEL=$PACKAGE_LEVEL)"
 
-  assert_import_ok "pywbem"
-  assert_import_ok "pywbem_mock"
-  assert_no_moftab_build
-  remove_virtualenv "$testcase"
-  cleanup_egg_file
-}
-
-# Install test via setup.py has been disabled
-function test2()
-{
-  testcase="test2"
-  info "Testcase $testcase: setup.py install from repo root directory: $ROOT_DIR (deprecated by setuptools)"
-  make_virtualenv "$testcase"
-
-  call "cd $ROOT_DIR; python setup.py install" "Installing with setup.py from repo root directory (latest package levels)"
-
-  assert_import_ok "pywbem"
-  assert_import_ok "pywbem_mock"
+  list_virtualenv "$TMP_TEST_DIR" "Python packages in virtualenv after installation (PACKAGE_LEVEL=$PACKAGE_LEVEL)"
+  assert_import_ok "pywbem" "$TMP_TEST_DIR"
+  assert_import_ok "pywbem_mock" "$TMP_TEST_DIR"
   assert_no_moftab_build
   remove_virtualenv "$testcase"
   cleanup_egg_file
@@ -490,13 +503,15 @@ function test2()
 function test3()
 {
   testcase="test3"
-  info "Testcase $testcase: Pip install from wheel distribution archive: $WHL_DISTFILE"
+  heading "Testcase $testcase: Pip install from wheel distribution archive: $WHL_DISTFILE"
   make_virtualenv "$testcase"
+  list_virtualenv "$TMP_TEST_DIR" "Python packages in virtualenv before installation (PACKAGE_LEVEL=$PACKAGE_LEVEL)"
 
   call "cd $TMP_TEST_DIR; pip install $(abspath $WHL_DISTFILE) $PIP_OPTS" "Installing with pip from wheel distribution archive (PACKAGE_LEVEL=$PACKAGE_LEVEL)"
 
-  assert_import_ok "pywbem"
-  assert_import_ok "pywbem_mock"
+  list_virtualenv "$TMP_TEST_DIR" "Python packages in virtualenv after installation (PACKAGE_LEVEL=$PACKAGE_LEVEL)"
+  assert_import_ok "pywbem" "$TMP_TEST_DIR"
+  assert_import_ok "pywbem_mock" "$TMP_TEST_DIR"
   assert_no_moftab_build
   remove_virtualenv "$testcase"
   cleanup_egg_file
@@ -505,30 +520,15 @@ function test3()
 function test4()
 {
   testcase="test4"
-  info "Testcase $testcase: Pip install from source distribution archive: $SRC_DISTFILE"
+  heading "Testcase $testcase: Pip install from source distribution archive: $SRC_DISTFILE"
   make_virtualenv "$testcase"
+  list_virtualenv "$TMP_TEST_DIR" "Python packages in virtualenv before installation (PACKAGE_LEVEL=$PACKAGE_LEVEL)"
 
   call "cd $TMP_TEST_DIR; pip install $(abspath $SRC_DISTFILE) $PIP_OPTS" "Installing with pip from source distribution archive (PACKAGE_LEVEL=$PACKAGE_LEVEL)"
 
-  assert_import_ok "pywbem"
-  assert_import_ok "pywbem_mock"
-  assert_no_moftab_build
-  remove_virtualenv "$testcase"
-  cleanup_egg_file
-}
-
-# Install test via setup.py has been disabled
-function test5()
-{
-  testcase="test5"
-  info "Testcase $testcase: setup.py install from unpacked source distribution archive: $SRC_DISTFILE (deprecated by setuptools)"
-  make_virtualenv "$testcase"
-  run "tar -x -v -f $SRC_DISTFILE -C $SRC_DISTFILE_UNPACK_DIR" "Unpacking source distribution archive to: $SRC_DISTFILE_UNPACK_DIR"
-
-  call "cd $SRC_DISTFILE_UNPACK_DIR/$SRC_DISTFILE_TOP_DIR; python setup.py install" "Installing with setup.py from unpack directory: $SRC_DISTFILE_UNPACK_DIR/$SRC_DISTFILE_TOP_DIR (latest package levels)"
-
-  assert_import_ok "pywbem"
-  assert_import_ok "pywbem_mock"
+  list_virtualenv "$TMP_TEST_DIR" "Python packages in virtualenv after installation (PACKAGE_LEVEL=$PACKAGE_LEVEL)"
+  assert_import_ok "pywbem" "$TMP_TEST_DIR"
+  assert_import_ok "pywbem_mock" "$TMP_TEST_DIR"
   assert_no_moftab_build
   remove_virtualenv "$testcase"
   cleanup_egg_file
@@ -536,8 +536,8 @@ function test5()
 
 #----- main
 
-WHL_DISTFILE="$1"  # absolute or relative to caller's cwd
-SRC_DISTFILE="$2"  # absolute or relative to caller's cwd
+WHL_DISTFILE=$(abspath "$1")  # absolute or relative to caller's cwd
+SRC_DISTFILE=$(abspath "$2")  # absolute or relative to caller's cwd
 PYTHON_CMD="$3"    # Python command to use (outside of the created virtualenvs)
 
 if [[ -z $PYTHON_CMD ]]; then
@@ -565,4 +565,4 @@ test4
 
 cleanup
 
-info "All testcases succeeded."
+heading "All testcases succeeded."
